%%% The main file for replicating "Out-of-sample equity premium prediction:
%%% combination forcasts and links to the real economy", by Rapach, Strauss
%%% and Zhou (2010 RFS)
%%% In order to run the code it is necessary to download the Econometrics 
%%% Toolbox by James P. LeSage that you find at this link: 
%%% https://www.spatial-econometrics.com/

clc;
clear;


%%
% get the data - updated data: 1947Q1-2016Q4
run('getdata2016.m');
clear;
load('data2016.mat');
%%%%%comment these lines out to perform computations for the updated sample
GW = GW(1:236,:);   %restrict to the original sample (1947Q1-2005Q4)
Rfree = Rfree(1:236,:); %restrict to the original sample (1947Q1-2005Q4)
r = r(1:236,:);  %restrict to the original sample (1947Q1-2005Q4)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

variablename1 = {'D/P' 'D/Y' 'E/P' 'D/E' 'SVAR' 'B/M' 'NTIS' 'TBL' 'LTY' 'LTR' 'TMS' 'DFY' 'DFR' 'INFL' 'I/K'};
variablename2 = {'Mean' 'Median' 'Trimmed mean' 'DMSPE, \theta = 1.0' 'DMSPE, \theta = 0.9'};
variablename = {'D/P' 'D/Y' 'E/P' 'D/E' 'SVAR' 'B/M' 'NTIS' 'TBL' 'LTY' 'LTR' 'TMS' 'DFY' 'DFR' 'INFL' 'I/K' ...
    'Mean' 'Median' 'Trimmed mean' 'DMSPE, \theta = 1.0' 'DMSPE, \theta = 0.9' 'HA'};

global T K q0 theta_1 theta_2 window gamma w_UB w_LB

T = length(r);
K = size(GW,2);
q0 = 40;                                    % initial holdout period
theta_1 = 1;                                %%discount factor : when theta=1 there is no discounting, and the we produce the optimal combination forecast derived by Bates and Granger (1969)
theta_2 = 0.9;                               %% theta <1 means that more weight is attached to recent forecast accuracy
window = 4*10;                              % the window for estimating variance of stock returns (to calculate CER)
gamma = 3;                                  % RRA parameter
w_UB = 1.5;
w_LB = 0;

% disp('Equity risk premium, ann % summary stats (mean, vol, Sharpe ratio)');
% disp([12*mean(r) sqrt(12)*std(r) sqrt(12)*mean(r)/std(r)]);
% 
% stats_GW=[mean(GW)' median(GW)' prctile(GW,1)' prctile(GW,99)' std(GW)'];
% disp('Predictor variables, summary stats');
% disp('Mean, median, 1st percentile, 99th percentile, std dev');
% disp(stats_GW);

% rho_GW=nan(size(GW,2));
% for i=1:size(GW,2);
%     rho_GW(i)=corr(GW(2:end,i),GW(1:end-1,i));
% end;


%% get the out-of-sample R-squared for one-quarter forecast horizon

q = [164 120 24]+q0;                        % the length of three out-of sample period


R2OS_PR = nan(length(q),K);
R2OS_combine = nan(length(q),5);
t_MSPE_PR = nan(length(q),K);
t_MSPE_combine = nan(length(q),5);
CER_gain_PR = nan(length(q),K);
CER_gain_combine = nan(length(q),5);

for i = 1:3
    m = T -q(i);
    actual_r = r(end-q(i)+1:end);
    
    FC_PM = nan(q(i),1);                    % forecasts using historical mean
    FC_PR = nan(q(i),K);                    % forecasts using predictors
    FC_KS = nan(q(i),1);                    % forecasts using kitchen sink model
    FC_vol = nan(q(i),1);                   % forecasts of volatility, using 40 quarters rolling window
    
    for k = 1:q(i)
        FC_PM(k) = mean(r(1:m+(k-1)));
        if m+k-1 <= window-1
            FC_vol(k) = std(r(1:m+k-1));
        else
            FC_vol(k)=std(r(m+k-1-(window-1):m+k-1));
        end;
    end
    
    for k = 1:q(i)
        for j = 1:K
            X = [ones(m+k-2,1) GW(1:m+k-2,j)];
            results_ols=ols(r(2:m+k-1),X);
            FC_PR(k,j)=[1 GW(m+k-1,j)]*results_ols.beta;
        end
        
        % kitchen sink model
        X_KS = [ones(m+k-2,1) GW(1:m+k-2,:)];
        results_ols=ols(r(2:m+k-1),X_KS);
        FC_KS(k)=[1 GW(m+k-1,:)]*results_ols.beta;
    end
    
    u_PM = actual_r-FC_PM;   %% forecast error for historical mean 
    u_PR = kron(ones(1,K),actual_r)-FC_PR;  %% forecast error for each predictor

    omega_1 = nan(q(i),K);
    omega_2 = nan(q(i),K);
    for t = q0+1:q(i)
        tempweight1 = nan(t-1,1);
        tempweight2 = nan(t-1,1);
        for s = 1:length(tempweight1)
            tempweight1(s) = theta_1^(length(tempweight1)-s);
            tempweight2(s) = theta_2^(length(tempweight2)-s);
        end
        temperror = u_PR(1:t-1,:);
        temperror2 = temperror.^2;
        phi_1 = (tempweight1'*temperror2).^(-1); %%equation (6) in the paper
        phi_2 = (tempweight2'*temperror2).^(-1);  %%equation (6) in the paper
        omega_1(t,:) = phi_1/(sum(phi_1));  %% equation (5) in the paper 
        omega_2(t,:) = phi_2/(sum(phi_2));  %% equation (5) in the paper 
    end
    
    DMSPE_1 = sum(omega_1.*FC_PR,2);  %%DMSPE forecast with theta=1
    DMSPE_2 = sum(omega_2.*FC_PR,2);   %%DMSPE forecast with theta=0.9
    mean_FC_PR =  mean(FC_PR,2);       %% simple mean combianation scheme
    median_FC_PR = median(FC_PR,2);    %% meadian combination scheme
    trimmean_FC_PR = trimmean(FC_PR,7,2);               % 7 is for excluding the highest and the lowest value of forecasts
    FC_combine = [mean_FC_PR median_FC_PR trimmean_FC_PR DMSPE_1 DMSPE_2];
    
    %now we evaluate respective out-of-sample predictive accuracy of the
    %different weighting schemes
    

    u_combine = kron(ones(1,5),actual_r)-FC_combine;
    u_PM_evalution = u_PM(q0+1:end,:);
    u_PR_evalution = u_PR(q0+1:end,:);
    u_combine_evalution = u_combine(q0+1:end,:);
    MSFE_PM = mean(u_PM_evalution.^2);
    MSFE_PR = mean(u_PR_evalution.^2);
    MSFE_combine = mean(u_combine_evalution.^2);
    R2OS_PR(i,:) = 100*(1-MSFE_PR/MSFE_PM);
    R2OS_combine(i,:) = 100*(1-MSFE_combine/MSFE_PM);
    
    
    w_PM = (1/gamma)*FC_PM./(FC_vol.^2);
    w_PR = (1/gamma)*FC_PR./(kron(ones(1,K),FC_vol).^2);
    w_combine = (1/gamma)*FC_combine./(kron(ones(1,5),FC_vol).^2); 
    w_PM(find(w_PM > w_UB)) = w_UB;  %see descriptions below table 1: weights are restricted to be between 0 and 1.5
    w_PM(find(w_PM < w_LB)) = w_LB;   %see descriptions below table 1: weights are restricted to be between 0 and 1.5
    w_PR(find(w_PR > w_UB)) = w_UB;   %see descriptions below table 1: weights are restricted to be between 0 and 1.5
    w_PR(find(w_PR < w_LB)) = w_LB;   %see descriptions below table 1: weights are restricted to be between 0 and 1.5
    w_combine(find(w_combine > w_UB)) = w_UB;  %see descriptions below table 1: weights are restricted to be between 0 and 1.5
    w_combine(find(w_combine < w_LB)) = w_LB;  %see descriptions below table 1: weights are restricted to be between 0 and 1.5
    
    R_PM = Rfree(end-q(i)+1:end)+w_PM.*actual_r;
    R_PR = kron(ones(1,K),Rfree(end-q(i)+1:end))+w_PR.*kron(ones(1,K),actual_r);
    R_combine = kron(ones(1,5),Rfree(end-q(i)+1:end))+w_combine.*kron(ones(1,5),actual_r);
    R_PM_evaluation = R_PM(q0+1:end,:);
    R_PR_evaluation = R_PR(q0+1:end,:);
    R_combine_evaluation = R_combine(q0+1:end,:);
    CER_PM = 400*(mean(R_PM_evaluation)-0.5*gamma*std(R_PM_evaluation).^2);
    CER_PR = 400*(mean(R_PR_evaluation)-0.5*gamma*std(R_PR_evaluation).^2);
    CER_combine = 400*(mean(R_combine_evaluation)-0.5*gamma*std(R_combine_evaluation).^2);
    CER_gain_PR(i,:) = CER_PR-CER_PM;
    CER_gain_combine(i,:) = CER_combine-CER_PM;
    
    
    % Clark and West (2007) MSPE-adjusted statistic, for individual
    % forecasts
    f1 = u_PM_evalution.^2;
    f2 = u_PR_evalution.^2;
    f3 = (u_PR_evalution-kron(ones(1,K),u_PM_evalution)).^2;
    f = kron(ones(1,K),f1)-f2+f3;
    for l = 1:K
        f_ols = ols(f(:,l),ones(size(f,1),1));
        t_MSPE_PR(i,l) = f_ols.tstat;
    end
    
    % Clark and West (2007) MSPE-adjusted statistic, for combined forecasts
    f1 = u_PM_evalution.^2;
    f2 = u_combine_evalution.^2;
    f3 = (u_combine_evalution-kron(ones(1,5),u_PM_evalution)).^2;
    f = kron(ones(1,5),f1)-f2+f3;
    for l = 1:5
        f_ols = ols(f(:,l),ones(size(f,1),1));
        t_MSPE_combine(i,l) = f_ols.tstat;
    end

    % for the 1st out-of-sample, get the cumulative squared error and
    % forecasts
    if i == 1
        cumerror_PM = cumsum(u_PM_evalution.^2);
        cumerror_PR = cumsum(u_PR_evalution.^2);
        cumerror_combine = cumsum(u_combine_evalution.^2);
        cumerror_dif1 = kron(ones(1,K),cumerror_PM) - cumerror_PR;          % for figure 1
        cumerror_dif2 = kron(ones(1,5),cumerror_PM) - cumerror_combine;     % for figure 2
        forecast = [FC_PR(q0+1:end,:) FC_combine(q0+1:end,:)];              % for figure 3-6
        forecast_historical = FC_PM(q0+1:end,:);                            % for figure 3-6
        forecast_KS = FC_KS(q0+1:end,:);                                    % for figure 5
        corr_forecasts = corr(FC_PR(q0+1:end,:));                           % for table 3 
        
        % 's1h1' means the sample 1 and horizon 1, used for table 5
        u_PM_evalution_s1h1 = u_PM_evalution;
        u_combine_evalution_s1h1 = u_combine_evalution;
        f_s1h1 = f;
        
        % get the MHLN stats and its pvalue
        u = [u_PR_evalution u_combine_evalution];
        t_temp = size(u,1);
        d = nan(size(u,1),size(u,2),size(u,2));
        for t = 1:t_temp
            u_temp = u(t,:);
            d(t,:,:) = kron(ones(length(u_temp),1),u_temp.^2) - u_temp'*u_temp;
        end
        d_bar = squeeze(mean(d,1));
        for t = 1:t_temp
            phi_0(t,:,:) = (d(t,:,:)-mean(d,1)).^2;
        end
        phi_0 = squeeze(mean(phi_0,1));
        V_hat = phi_0/t_temp;
        MHLN = (t_temp-1)*(V_hat.^(-0.5).*d_bar)/t_temp;
        MHLN_pvalue = 1-tcdf(MHLN,t_temp-1);                                % for table 2
    end
end

% get the p-value for MSPE
p_MSPE_PR = 1-normcdf(t_MSPE_PR);
p_MSPE_combine = 1-normcdf(t_MSPE_combine);


%% get the out-of-sample R-squared for four-quarter horizon

m = T -q(1);
h = 4;
% r_h4 = r(1:end-3)+r(2:end-2)+r(3:end-1)+r(4:end);
r_h4 = (1+r(1:end-3)).*(1+r(2:end-2)).*(1+r(3:end-1)).*(1+r(4:end))-1;

actual_r = r_h4(m+1:end);

FC_PM = nan(q(1)-h+1,1);                    % forecasts using historical mean
FC_PR = nan(q(1)-h+1,K);                    % forecasts using predictors

for k = 1:q(1)-h+1
    FC_PM(k) = mean(r_h4(1:m+(k-h)));
end

for k = 1:q(1)-h+1
    for j = 1:K
        X = [ones(m+k-h-1,1) GW(1:m+k-h-1,j)];
        results_ols=ols(r(2:m+k-h),X);
        FC_PR(k,j)=[1 GW(m+k-h-1,j)]*results_ols.beta;
    end
end

u_PM = actual_r-FC_PM;
u_PR = kron(ones(1,K),actual_r)-FC_PR;

omega_1 = nan(q(1)-h+1,K);
omega_2 = nan(q(1)-h+1,K);
for t = q0+1:q(1)-h+1
    tempweight1 = nan(t-h,1);
    tempweight2 = nan(t-h,1);
    for s = 1:length(tempweight1)
        tempweight1(s) = theta_1^(length(tempweight1)-s);
        tempweight2(s) = theta_2^(length(tempweight2)-s);
    end
    temperror = u_PR(1:t-h,:);
    temperror2 = temperror.^2;
    phi_1 = (tempweight1'*temperror2).^(-1);
    phi_2 = (tempweight2'*temperror2).^(-1);
    omega_1(t,:) = phi_1/(sum(phi_1));
    omega_2(t,:) = phi_2/(sum(phi_2));
end

DMSPE_1 = sum(omega_1.*FC_PR,2);
DMSPE_2 = sum(omega_2.*FC_PR,2);
mean_FC_PR =  mean(FC_PR,2);
median_FC_PR = median(FC_PR,2);
trimmean_FC_PR = trimmean(FC_PR,7,2);               % 7 is for excluding the highest and the lowest value of forecasts
FC_combine = [mean_FC_PR median_FC_PR trimmean_FC_PR DMSPE_1 DMSPE_2];

u_PM = actual_r-FC_PM;
u_combine = kron(ones(1,5),actual_r)-FC_combine;
u_PM_evalution = u_PM(q0+1:end,:);
u_combine_evalution = u_combine(q0+1:end,:);
MSFE_PM = mean(u_PM_evalution.^2);
MSFE_combine = mean(u_combine_evalution.^2);
R2OS_combine_h4 = 100*(1-MSFE_combine/MSFE_PM);

% Clark and West (2007) MSPE-adjusted statistic, for combined forecasts
f1 = u_PM_evalution.^2;
f2 = u_combine_evalution.^2;
f3 = (u_combine_evalution-kron(ones(1,5),u_PM_evalution)).^2;
f = kron(ones(1,5),f1)-f2+f3;

for l = 1:5
    f_ols = ols(f(:,l),ones(size(f,1),1));
    t_MSPE_combine_h4(l) = f_ols.tstat;
end

p_MSPE_combine_h4 = 1-normcdf(t_MSPE_combine_h4);

% 's1h4' means the sample 1 and horizon 1, used for table 5
u_PM_evalution_s1h4 = u_PM_evalution;
u_combine_evalution_s1h4 = u_combine_evalution;
f_s1h4 = f;


%% macro-economic analysis

% get the macro data
input_file='macrodata.xlsx';
input_sheet='Sheet1';
macro = xlsread(input_file,input_sheet,'k27:q190');
variablename_macro = {'Real GDP growth' 'Real profit growth'  ...
    'Real profit growth (non-financial)' 'Real cash flow growth' ...
    'Real profit growth (CPI adjusted)' 'Real profit growth (non-financial, CPI adjusted)' ...
    'Real cash flow growth (CPI adjusted)'};

[corr_macro,p_corr_macro] = corrcoef([forecast(:,16:20),macro]);


R2OS_combine_s1h1 = nan(4,5,size(macro,2));
R2OS_combine_s1h4 = nan(4,5,size(macro,2));
t_MSPE_combine_s1h1 = nan(4,5,size(macro,2));
t_MSPE_combine_s1h4 = nan(4,5,size(macro,2));
for i = 1:size(macro,2)
    p33 = prctile(macro(:,i),100/3);
    p67 = prctile(macro(:,i),200/3); 
    period_good = find(macro(:,i)>=p67);
    period_normal = find(macro(:,i)>=p33 & macro(:,i)<p67);
    period_bad = find(macro(:,i)<p33);
    
    R2OS_combine_s1h1(:,:,i) = [100*(1-mean(u_combine_evalution_s1h1.^2)/mean(u_PM_evalution_s1h1.^2)); ...
        100*(1-mean(u_combine_evalution_s1h1(period_good,:).^2)/mean(u_PM_evalution_s1h1(period_good,:).^2)); ...
        100*(1-mean(u_combine_evalution_s1h1(period_normal,:).^2)/mean(u_PM_evalution_s1h1(period_normal,:).^2)); ...
        100*(1-mean(u_combine_evalution_s1h1(period_bad,:).^2)/mean(u_PM_evalution_s1h1(period_bad,:).^2))];
    
    for l = 1:5
        f_ols = ols(f_s1h1(:,l),ones(size(f_s1h1(:,l),1),1));
        f_ols_1 = ols(f_s1h1(period_good,l),ones(size(f_s1h1(period_good,l),1),1));
        f_ols_2 = ols(f_s1h1(period_normal,l),ones(size(f_s1h1(period_normal,l),1),1));
        f_ols_3 = ols(f_s1h1(period_bad,l),ones(size(f_s1h1(period_bad,l),1),1));
        t_MSPE_combine_s1h1(:,l,i) = [f_ols.tstat; f_ols_1.tstat; f_ols_2.tstat; f_ols_3.tstat]; 
    end
    
    
    p33 = prctile(macro(1:end-3,i),100/3);
    p67 = prctile(macro(1:end-3,i),200/3);   
    period_good = find(macro(1:end-3,i)>=p67);
    period_normal = find(macro(1:end-3,i)>=p33 & macro(1:end-3,i)<p67);
    period_bad = find(macro(1:end-3,i)<p33);
    
    R2OS_combine_s1h4(:,:,i) = [100*(1-mean(u_combine_evalution_s1h4.^2)/mean(u_PM_evalution_s1h4.^2)); ...
        100*(1-mean(u_combine_evalution_s1h4(period_good,:).^2)/mean(u_PM_evalution_s1h4(period_good,:).^2)); ...
        100*(1-mean(u_combine_evalution_s1h4(period_normal,:).^2)/mean(u_PM_evalution_s1h4(period_normal,:).^2)); ...
        100*(1-mean(u_combine_evalution_s1h4(period_bad,:).^2)/mean(u_PM_evalution_s1h4(period_bad,:).^2))];
    
    for l = 1:5
        f_ols = ols(f_s1h4(:,l),ones(size(f_s1h4(:,l),1),1));
        f_ols_1 = ols(f_s1h4(period_good,l),ones(size(f_s1h4(period_good,l),1),1));
        f_ols_2 = ols(f_s1h4(period_normal,l),ones(size(f_s1h4(period_normal,l),1),1));
        f_ols_3 = ols(f_s1h4(period_bad,l),ones(size(f_s1h4(period_bad,l),1),1));
        t_MSPE_combine_s1h4(:,l,i) = [f_ols.tstat; f_ols_1.tstat; f_ols_2.tstat; f_ols_3.tstat];
    end
end
p_MSPE_combine_s1h1 = 1-normcdf(t_MSPE_combine_s1h1);
p_MSPE_combine_s1h4 = 1-normcdf(t_MSPE_combine_s1h4);


%% figures and tables
% figure 1 to 7
run('graphs.m');

% table 1 to 5
output_file='output\results.xlsx';
output_sheet='out-of-sample';
xlswrite(output_file,variablename1',output_sheet,'a3');
xlswrite(output_file,variablename2',output_sheet,'a19');
xlswrite(output_file,R2OS_PR(1,:)',output_sheet,'b3');
xlswrite(output_file,R2OS_combine(1,:)',output_sheet,'b19');
xlswrite(output_file,R2OS_PR(2,:)',output_sheet,'f3');
xlswrite(output_file,R2OS_combine(2,:)',output_sheet,'f19');
xlswrite(output_file,R2OS_PR(3,:)',output_sheet,'j3');
xlswrite(output_file,R2OS_combine(3,:)',output_sheet,'j19');
 
xlswrite(output_file,p_MSPE_PR(1,:)',output_sheet,'c3');
xlswrite(output_file,p_MSPE_combine(1,:)',output_sheet,'c19');
xlswrite(output_file,p_MSPE_PR(2,:)',output_sheet,'g3');
xlswrite(output_file,p_MSPE_combine(2,:)',output_sheet,'g19');  
xlswrite(output_file,p_MSPE_PR(3,:)',output_sheet,'k3');
xlswrite(output_file,p_MSPE_combine(3,:)',output_sheet,'k19');

xlswrite(output_file,CER_gain_PR(1,:)',output_sheet,'d3');
xlswrite(output_file,CER_gain_combine(1,:)',output_sheet,'d19');
xlswrite(output_file,CER_gain_PR(2,:)',output_sheet,'h3');
xlswrite(output_file,CER_gain_combine(2,:)',output_sheet,'h19');
xlswrite(output_file,CER_gain_PR(3,:)',output_sheet,'l3');
xlswrite(output_file,CER_gain_combine(3,:)',output_sheet,'l19');

output_sheet='MHLN';
xlswrite(output_file,variablename(1:20),output_sheet,'b1');
xlswrite(output_file,variablename(1:20)',output_sheet,'a2');
xlswrite(output_file,MHLN_pvalue,output_sheet,'b2');

output_sheet='correlation matrix';
xlswrite(output_file,variablename1,output_sheet,'b1');
xlswrite(output_file,variablename1',output_sheet,'a2');
xlswrite(output_file,corr_forecasts,output_sheet,'b2');

output_sheet='correlation macro';
xlswrite(output_file,variablename_macro,output_sheet,'b1');
xlswrite(output_file,variablename2',output_sheet,'a2');
xlswrite(output_file,corr_macro(1:5,6:12),output_sheet,'b2');
xlswrite(output_file,p_corr_macro(1:5,6:12),output_sheet,'b7');

output_sheet='R2OS-sortbymacro';
xlswrite(output_file,variablename2',output_sheet,'a5');
xlswrite(output_file,variablename2',output_sheet,'a11');
xlswrite(output_file,variablename2',output_sheet,'a17');
xlswrite(output_file,variablename2',output_sheet,'a23');
xlswrite(output_file,variablename2',output_sheet,'a29');
xlswrite(output_file,variablename2',output_sheet,'a35');
xlswrite(output_file,variablename2',output_sheet,'a41');

xlswrite(output_file,R2OS_combine_s1h1(:,:,1)',output_sheet,'b5');
xlswrite(output_file,R2OS_combine_s1h1(:,:,2)',output_sheet,'b11');
xlswrite(output_file,R2OS_combine_s1h1(:,:,3)',output_sheet,'b17');
xlswrite(output_file,R2OS_combine_s1h1(:,:,4)',output_sheet,'b23');
xlswrite(output_file,R2OS_combine_s1h1(:,:,5)',output_sheet,'b29');
xlswrite(output_file,R2OS_combine_s1h1(:,:,6)',output_sheet,'b35');
xlswrite(output_file,R2OS_combine_s1h1(:,:,7)',output_sheet,'b41');

xlswrite(output_file,R2OS_combine_s1h4(:,:,1)',output_sheet,'g5');
xlswrite(output_file,R2OS_combine_s1h4(:,:,2)',output_sheet,'g11');
xlswrite(output_file,R2OS_combine_s1h4(:,:,3)',output_sheet,'g17');
xlswrite(output_file,R2OS_combine_s1h4(:,:,4)',output_sheet,'g23');
xlswrite(output_file,R2OS_combine_s1h4(:,:,5)',output_sheet,'g29');
xlswrite(output_file,R2OS_combine_s1h4(:,:,6)',output_sheet,'g35');
xlswrite(output_file,R2OS_combine_s1h4(:,:,7)',output_sheet,'g41');

xlswrite(output_file,p_MSPE_combine_s1h1(:,:,1)',output_sheet,'l5');
xlswrite(output_file,p_MSPE_combine_s1h1(:,:,2)',output_sheet,'l11');
xlswrite(output_file,p_MSPE_combine_s1h1(:,:,3)',output_sheet,'l17');
xlswrite(output_file,p_MSPE_combine_s1h1(:,:,4)',output_sheet,'l23');
xlswrite(output_file,p_MSPE_combine_s1h1(:,:,5)',output_sheet,'l29');
xlswrite(output_file,p_MSPE_combine_s1h1(:,:,6)',output_sheet,'l35');
xlswrite(output_file,p_MSPE_combine_s1h1(:,:,7)',output_sheet,'l41');

xlswrite(output_file,p_MSPE_combine_s1h4(:,:,1)',output_sheet,'q5');
xlswrite(output_file,p_MSPE_combine_s1h4(:,:,2)',output_sheet,'q11');
xlswrite(output_file,p_MSPE_combine_s1h4(:,:,3)',output_sheet,'q17');
xlswrite(output_file,p_MSPE_combine_s1h4(:,:,4)',output_sheet,'q23');
xlswrite(output_file,p_MSPE_combine_s1h4(:,:,5)',output_sheet,'q29');
xlswrite(output_file,p_MSPE_combine_s1h4(:,:,6)',output_sheet,'q35');
xlswrite(output_file,p_MSPE_combine_s1h4(:,:,7)',output_sheet,'q41');